summaryrefslogtreecommitdiffstats
path: root/platform/linuxbsd/export/export_plugin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'platform/linuxbsd/export/export_plugin.cpp')
-rw-r--r--platform/linuxbsd/export/export_plugin.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/platform/linuxbsd/export/export_plugin.cpp b/platform/linuxbsd/export/export_plugin.cpp
index daa2664b09..082040c8d6 100644
--- a/platform/linuxbsd/export/export_plugin.cpp
+++ b/platform/linuxbsd/export/export_plugin.cpp
@@ -95,15 +95,15 @@ Error EditorExportPlatformLinuxBSD::export_project(const Ref<EditorExportPreset>
return err;
}
// Save console script.
if (err == OK) {
- int con_scr = p_preset->get("debug/export_console_script");
+ int con_scr = p_preset->get("debug/export_console_wrapper");
if ((con_scr == 1 && p_debug) || (con_scr == 2)) {
String scr_path = path.get_basename() + ".sh";
err = _export_debug_script(p_preset, pkg_name, path.get_file(), scr_path);
FileAccess::set_unix_permissions(scr_path, 0755);
if (err != OK) {
- add_message(EXPORT_MESSAGE_ERROR, TTR("Debug Script Export"), TTR("Could not create console script."));
+ add_message(EXPORT_MESSAGE_ERROR, TTR("Debug Console Export"), TTR("Could not create console wrapper."));
}
}
}
@@ -95,15 +95,15 @@ Error EditorExportPlatformLinuxBSD::export_project(const Ref<EditorExportPreset>
return err;
}
- // Save console script.
+ // Save console wrapper.
if (err == OK) {